# ../scripts/custom/gg_winner_menu/gg_winner_menu_config.py

# =============================================================================
# >> IMPORTS
# =============================================================================
# Python Imports
from __future__ import with_statement
from path import path

# GunGame Imports
from gungame51.core.cfg.configs import ConfigContextManager


# =============================================================================
# >> LOAD & UNLOAD
# =============================================================================
def load():

    # Create the cfg file
    with ConfigContextManager(
      path(__file__).parent.split('scripts')[~0][1:]) as config:

        # Create the gg_winner_menu instance
        with config.cfg_cvar('gg_winner_menu') as cvar:

            cvar.name = 'WINNER MENU'
            cvar.description.append('Winner chooses next game type.')
            cvar.options.append('0 = (Disabled) Do not load gg_winner_menu.')
            cvar.options.append('1 = (Enabled) Load gg_winner_menu.')
            cvar.default = 0
            cvar.text = 'Enables/Disables gg_winner_menu.'

        # Create the gg_winner_menu_default_random instance
        with config.cfg_cvar('gg_winner_menu_default_random') as cvar:

            cvar.name = 'RANDOM DEFAULT GAMEMODE'
            cvar.description.append('A random gamemode ' +
                'will be chosen when gg_winner_menu is loaded.')
            cvar.options.append('0 = Do not choose a ' +
                'random gamemode when gg_winner_menu is loaded.')
            cvar.options.append('1 = Choose a random ' +
                'gamemode when gg_winner_menu is loaded.')
            cvar.default = 0
            cvar.text = (
                'Choose a random gamemode when gg_winner_menu is loaded.')

        # Create the gg_winner_menu_default instance
        with config.cfg_cvar('gg_winner_menu_default') as cvar:

            cvar.name = 'DEFAULT GAMEMODE'
            cvar.description.append('Set to the name of the gamemode ' +
                'that should be enabled when GunGame is first loaded')
            cvar.notes.append('The gamemode must match ' +
                '"exactly" to the name of one of the modes ' +
                'in your gg_winner_menu_gametypes.ini file.')
            cvar.notes.append('gg_winner_menu_default_random ' +
                '"must" be set to 0 for this gamemode to be set')
            cvar.default = ''
            cvar.text = (
                'The gamemode to be enabled when GunGame is first loaded')

        # Create the gg_winner_menu_random instance
        with config.cfg_cvar('gg_winner_menu_random') as cvar:

            cvar.name = 'RANDOMIZED WINNER MENU'
            cvar.description.append('If there are less than 9 ' +
                'game types available, still randomize the list.')
            cvar.description.append('When more than 9 are available, ' +
                'they will always be selected and shown at random.')
            cvar.options.append('0 = (Disabled) Do not ' +
                'randomize the list if there are 9 or fewer game types.')
            cvar.options.append('1 = (Enabled) Randomize ' +
                'the list if there are 9 or fewer game types.')
            cvar.default = 0
            cvar.text = ('Randomize the Winner Menu if ' +
                'there are more than 9 available game types.')

        # Create the gg_winner_menu_allow_bots instance
        with config.cfg_cvar('gg_winner_menu_allow_bots') as cvar:

            cvar.name = 'ALLOW BOTS TO VOTE'
            cvar.description.append('If enabled, if a ' +
                'Bot wins, a random gamemode will be chosen.')
            cvar.options.append(
                '0 = Do not choose a random gamemode if a Bot wins.')
            cvar.options.append('1 = Choose a random gamemode if a Bot wins.')
            cvar.default = 0
            cvar.text = 'Choose a random gamemode if a Bot wins.'

        # Create the gg_winner_menu_team_most_kills instance
        with config.cfg_cvar('gg_winner_menu_team_most_kills') as cvar:

            cvar.name = 'TEAM GAME MOST KILLS'
            cvar.description.append(
                'If enabled, when playing a team-based addon (gg_teamplay, ' +
                'gg_teamplay_deathmatch, or gg_teamwork), the player with ' +
                'the most kills on the winning team will receive the menu.')
            cvar.options.append('0 = The player on the winning ' +
                'team that gets the last kill will receive the menu.')
            cvar.options.append('1 = The player on the winning ' +
                'team with the most kills will receive the menu.')
            cvar.default = 0
            cvar.text = (
                'When playing a team-based addon, the player with the ' +
                'most kills on the winning team will receive the menu.')
